diff -r 94186a96ca17 PATCHES
--- a/PATCHES	Tue Nov 24 21:45:58 2015 -0800
+++ b/PATCHES	Wed Nov 25 17:59:35 2015 +0100
@@ -0,0 +1,1 @@
+patch-1.5.24.aw.timeouthook.1
diff -r 94186a96ca17 curs_main.c
--- a/curs_main.c	Tue Nov 24 21:45:58 2015 -0800
+++ b/curs_main.c	Wed Nov 25 17:59:35 2015 +0100
@@ -681,8 +681,10 @@
 
       dprint(4, (debugfile, "mutt_index_menu[%d]: Got op %d\n", __LINE__, op));
 
-      if (op == -1)
-	continue; /* either user abort or timeout */
+      if (op == -1) {
+        mutt_timeout_hook(".");
+ 	continue; /* either user abort or timeout */
+      }
 
       mutt_curs_set (1);
 
diff -r 94186a96ca17 hook.c
--- a/hook.c	Tue Nov 24 21:45:58 2015 -0800
+++ b/hook.c	Wed Nov 25 17:59:35 2015 +0100
@@ -142,7 +142,7 @@
 	ptr->rx.not == not &&
 	!mutt_strcmp (pattern.data, ptr->rx.pattern))
     {
-      if (data & (M_FOLDERHOOK | M_SENDHOOK | M_SEND2HOOK | M_MESSAGEHOOK | M_ACCOUNTHOOK | M_REPLYHOOK | M_CRYPTHOOK))
+      if (data & (M_FOLDERHOOK | M_SENDHOOK | M_SEND2HOOK | M_MESSAGEHOOK | M_ACCOUNTHOOK | M_REPLYHOOK | M_CRYPTHOOK | M_TIMEOUTHOOK))
       {
 	/* these hooks allow multiple commands with the same
 	 * pattern, so if we've already seen this pattern/command pair, just
@@ -494,6 +494,33 @@
   return _mutt_list_hook (adr->mailbox, M_CRYPTHOOK);
 }
 
+
+void mutt_timeout_hook (const char *chs)
+{
+  HOOK* hook;
+  BUFFER token;
+  BUFFER err;
+  char buf[STRING];
+
+  err.data = buf;
+  err.dsize = sizeof (buf);
+  memset (&token, 0, sizeof (token));
+
+  for (hook = Hooks; hook; hook = hook->next)
+  {
+    if (! (hook->command && (hook->type & M_TIMEOUTHOOK)))
+      continue;
+
+    if (mutt_parse_rc_line (hook->command, &token, &err) == -1)
+    {
+      FREE (&token.data);
+      mutt_error ("%s", err.data);
+      mutt_sleep (1);
+
+      return;
+    }
+  }
+}
 #ifdef USE_SOCKET
 void mutt_account_hook (const char* url)
 {
diff -r 94186a96ca17 init.h
--- a/init.h	Tue Nov 24 21:45:58 2015 -0800
+++ b/init.h	Wed Nov 25 17:59:35 2015 +0100
@@ -3683,6 +3683,7 @@
   { "spam",		parse_spam_list,	M_SPAM },
   { "nospam",		parse_spam_list,	M_NOSPAM },
   { "subscribe",	parse_subscribe,	0 },
+  { "timeout-hook",	mutt_parse_hook,	M_TIMEOUTHOOK },
   { "toggle",		parse_set,		M_SET_INV },
   { "unalias",		parse_unalias,		0 },
   { "unalternative_order",parse_unlist,		UL &AlternativeOrderList },
diff -r 94186a96ca17 mutt.h
--- a/mutt.h	Tue Nov 24 21:45:58 2015 -0800
+++ b/mutt.h	Wed Nov 25 17:59:35 2015 +0100
@@ -141,6 +141,7 @@
 #define M_ACCOUNTHOOK	(1<<9)
 #define M_REPLYHOOK	(1<<10)
 #define M_SEND2HOOK     (1<<11)
+#define M_TIMEOUTHOOK	(1<<12)
 
 /* tree characters for linearize_tree and print_enriched_string */
 #define M_TREE_LLCORNER		1
diff -r 94186a96ca17 protos.h
--- a/protos.h	Tue Nov 24 21:45:58 2015 -0800
+++ b/protos.h	Wed Nov 25 17:59:35 2015 +0100
@@ -148,6 +148,7 @@
 char *mutt_get_parameter (const char *, PARAMETER *);
 LIST *mutt_crypt_hook (ADDRESS *);
 char *mutt_make_date (char *, size_t);
+void mutt_timeout_hook (const char *);
 
 const char *mutt_make_version (void);
 
